@@ -11,7 +11,7 @@
     copyright: (C) 2002 by Dario Abatianni
     email:     eisfuchs@tigress.com
 
-    $Id: channel.cpp,v 1.45 2003/02/05 20:16:55 eisfuchs Exp $
+    $Id: channel.cpp,v 1.53 2003/02/23 18:09:27 eisfuchs Exp $
 */
 
 #include <qvbox.h>
@@ -30,6 +30,10 @@
 #include "konversationapplication.h"
 #include "channel.h"
 
+#if QT_VERSION < 0x030100
+#include "main.h"
+#endif
+
 Channel::Channel(QWidget* parent) : ChatWindow(parent)
 {
   // init variables
@@ -56,9 +60,6 @@ Channel::Channel(QWidget* parent) : ChatWindow(parent)
   QSizePolicy greedy=QSizePolicy(QSizePolicy::MinimumExpanding,QSizePolicy::MinimumExpanding);
 
   // (this) The main Box, holding the channel view/topic and the input line
-  setSpacing(spacing());
-  setMargin(margin());
-
   splitter=new QSplitter(this);
   setStretchFactor(splitter,10);
   splitter->setOpaqueResize(true);
@@ -115,14 +116,10 @@ Channel::Channel(QWidget* parent) : ChatWindow(parent)
 
   setTextView(new IRCView(topicViewNicksGrid,NULL));  // Server will be set later in setServer()
 
-//  nicksOps=new QLabel(i18n("Nicks"),topicViewNicksGrid);
-
   // The box that holds the Nick List and the quick action buttons
   QVBox* nickListButtons=new QVBox(splitter);
-
   nickListButtons->setSpacing(spacing());
 
-//  nicksOps=new QLabel(i18n("Nicks"),topicViewNicksGrid);
   nicksOps=new QLabel(i18n("Nicks"),nickListButtons);
   nicksOps->setAlignment(AlignVCenter | AlignHCenter);
 
@@ -200,6 +197,7 @@ Channel::Channel(QWidget* parent) : ChatWindow(parent)
   connect(textView,SIGNAL (gotFocus()),this,SLOT (adjustFocus()) );
 
   connect(nicknameListView,SIGNAL (popupCommand(int)),this,SLOT (popupCommand(int)) );
+  connect(nicknameListView,SIGNAL (doubleClicked(QListViewItem*)),this,SLOT (doubleClickCommand(QListViewItem*)) );
   connect(nicknameButton,SIGNAL (clicked()),this,SLOT (openNickChangeDialog()) );
 
   connect(topicLine,SIGNAL (topicChanged(const QString&)),this,SLOT (requestNewTopic(const QString&)) );
@@ -235,7 +233,7 @@ void Channel::requestNewTopic(const QString& newTopic)
   QTextCodec* codec=QTextCodec::codecForName(KonversationApplication::preferences.getCodec());
   topicLine->setCurrentText(codec->toUnicode(topic));
 
-  if(newTopic!=topic) sendChannelText("/TOPIC "+newTopic);
+  if(newTopic!=topic) sendChannelText(KonversationApplication::preferences.getCommandChar()+"TOPIC "+newTopic);
 
   channelInput->setFocus();
 }
@@ -281,9 +279,15 @@ void Channel::popupCommand(int id)
       pattern="WHOIS %u";
       raw=true;
       break;
-    case NickListView::Ping: /* Find out what number has to be put here! */
-      pattern="PRIVMSG %u :\x01PING 2398475\x01";
-      raw=true;
+    case NickListView::Ping:
+      {
+#if QT_VERSION < 0x030100
+        unsigned int time_t=toTime_t(QDateTime::currentDateTime());
+#else
+        unsigned int time_t=QDateTime::currentDateTime().toTime_t();
+#endif
+        pattern=QString(KonversationApplication::preferences.getCommandChar()+"CTCP %u PING %1").arg(time_t);
+      }
       break;
     case NickListView::Kick:
       pattern="KICK %c %u";
@@ -301,10 +305,10 @@ void Channel::popupCommand(int id)
   {
     pattern.replace(QRegExp("%c"),getName());
 
-    QStringList* nickList=getSelectedNicksList();
+    QStringList nickList=getSelectedNicksList();
 
     QString command;
-    for(QStringList::Iterator index=nickList->begin();index!=nickList->end();++index)
+    for(QStringList::Iterator index=nickList.begin();index!=nickList.end();++index)
     {
       command=pattern;
       command.replace(QRegExp("%u"),*index);
@@ -314,8 +318,16 @@ void Channel::popupCommand(int id)
       else
         sendChannelText(command);
     }
+  }
+}
 
-    delete nickList;
+// Will be connected to NickListView::doubleClicked()
+void Channel::doubleClickCommand(QListViewItem* item)
+{
+  if(item)
+  {
+    // TODO: put the quick button code in another function to make reusal more legitimate
+    quickButtonClicked(KonversationApplication::preferences.getChannelDoubleClickAction());
   }
 }
 
@@ -484,14 +496,14 @@ void Channel::setNickname(const QString& newNickname)
   nicknameButton->setText(newNickname);
 }
 
-QStringList* Channel::getSelectedNicksList()
+const QStringList& Channel::getSelectedNicksList()
 {
-  QStringList* selectedNicksList=new QStringList();
+  selectedNicksList.clear();
   Nick* nick=nicknameList.first();
 
   while(nick)
   {
-    if(nick->isSelected()) selectedNicksList->append(nick->getNickname());
+    if(nick->isSelected()) selectedNicksList.append(nick->getNickname());
     nick=nicknameList.next();
   }
 
@@ -1107,6 +1119,7 @@ void Channel::updateFonts()
 
   getTextView()->setFont(KonversationApplication::preferences.getTextFont());
   getTextView()->setPaper(QColor("#"+KonversationApplication::preferences.getTextViewBackground()));
+
   nicknameListView->setFont(KonversationApplication::preferences.getListFont());
 }
 
@@ -1114,8 +1127,10 @@ void Channel::openNickChangeDialog()
 {
   if(!nickChangeDialog)
   {
+    Identity identity=server->getIdentity();
+
     nickChangeDialog=new NickChangeDialog(this,server->getNickname(),
-                                          KonversationApplication::preferences.getNicknameList(),
+                                          identity.getNicknameList(),
                                           KonversationApplication::preferences.getNicknameSize());
     connect(nickChangeDialog,SIGNAL (closeDialog(QSize)),this,SLOT (closeNickChangeDialog(QSize)) );
     connect(nickChangeDialog,SIGNAL (newNickname(QString)),this,SLOT (changeNickname(QString)) );
