@@ -11,7 +11,7 @@
     copyright: (C) 2002 by Dario Abatianni
     email:     eisfuchs@tigress.com
 
-    $Id: channel.h,v 1.19 2003/01/28 12:20:49 eisfuchs Exp $
+    $Id: channel.h,v 1.22 2003/02/16 20:03:00 eisfuchs Exp $
 */
 
 #ifndef CHANNEL_H
@@ -23,8 +23,6 @@
 #include <qvbox.h>
 #include <qlabel.h>
 
-#include <kdialog.h>
-
 #include "nick.h"
 #include "nicklistview.h"
 #include "chatwindow.h"
@@ -88,8 +86,9 @@ class Channel : public ChatWindow
     void completeNick();
     void quickButtonClicked(QString definition);
     void modeButtonClicked(int id,bool on);
-    // Will be connected to NickListView::popupCommand(int)
-    void popupCommand(int id);
+
+    void popupCommand(int id);                // Will be connected to NickListView::popupCommand()
+    void doubleClickCommand(QListViewItem*);  // Will be connected to NickListView::doubleClicked()
     // Dialogs
     void openNickChangeDialog();
     void changeNickname(QString newNickname);
@@ -100,12 +99,9 @@ class Channel : public ChatWindow
     void textPasted(QString text);
 
   protected:
-    QStringList* getSelectedNicksList();
+    const QStringList& getSelectedNicksList();
     void showEvent(QShowEvent* event);
 
-    int spacing() {  return KDialog::spacingHint(); };
-    int margin() {  return KDialog::marginHint(); };
-
     int nicks;
     int ops;
 
@@ -145,6 +141,7 @@ class Channel : public ChatWindow
 
     NickChangeDialog* nickChangeDialog;
     QList<Nick> nicknameList;
+    QStringList selectedNicksList;
     QList<QuickButton> buttonList;
 };
 
