@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: chatwindow.cpp,v 1.20 2003/02/05 20:16:56 eisfuchs Exp $
+  $Id: chatwindow.cpp,v 1.22 2003/02/16 20:03:00 eisfuchs Exp $
 */
 
 #include <qdatetime.h>
@@ -29,6 +29,9 @@ ChatWindow::ChatWindow(QWidget* parent)
 {
   parentWidget=parent;
   firstLog=true;
+
+  setMargin(margin());
+  setSpacing(spacing());
 }
 
 ChatWindow::~ChatWindow()
@@ -84,6 +87,12 @@ void ChatWindow::setServer(Server* newServer)
   }
 }
 
+void ChatWindow::setIdentity(const Identity& newIdentity)
+{
+  identity=newIdentity;
+  filter.setIdentity(identity);
+}
+
 void ChatWindow::setTextView(IRCView* newView)
 {
   textView=newView;
@@ -214,12 +223,18 @@ void ChatWindow::logText(const QString& text)
 
 int ChatWindow::spacing()
 {
-  return KDialog::spacingHint();
+  if(KonversationApplication::preferences.getUseSpacing())
+    return KonversationApplication::preferences.getSpacing();
+  else
+    return KDialog::spacingHint();
 }
 
 int ChatWindow::margin()
 {
-  return KDialog::marginHint();
+  if(KonversationApplication::preferences.getUseSpacing())
+    return KonversationApplication::preferences.getMargin();
+  else
+    return KDialog::marginHint();
 }
 
 // Accessors
