@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: chatwindow.h,v 1.7 2003/01/28 12:20:49 eisfuchs Exp $
+  $Id: chatwindow.h,v 1.8 2003/02/10 16:39:43 eisfuchs Exp $
 */
 
 #ifndef CHATWINDOW_H
@@ -22,6 +22,7 @@
 
 #include "ircview.h"
 #include "outputfilter.h"
+#include "identity.h"
 
 /*
   @author Dario Abatianni
@@ -47,6 +48,7 @@ class ChatWindow : public QVBox
     };
 
     void setServer(Server* newServer);
+    void setIdentity(const Identity& newIdentity);
     void setTextView(IRCView* newView);
     IRCView* getTextView();
     void setLog(bool activate);
@@ -83,9 +85,10 @@ class ChatWindow : public QVBox
     QString logName;
 
     QFont font;
-    
+
     IRCView* textView;
     Server* server;
+    Identity identity;
     QFile logfile;
     OutputFilter filter;
     WindowType type;
