@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: dccpanel.cpp,v 1.17 2003/01/25 19:22:57 eisfuchs Exp $
+  $Id: dccpanel.cpp,v 1.18 2003/02/16 20:03:00 eisfuchs Exp $
 */
 
 #include <qhbox.h>
@@ -26,9 +26,6 @@
 DccPanel::DccPanel(QWidget* parent) :
           ChatWindow(parent)
 {
-  setSpacing(spacing());
-  setMargin(margin());
-
   setType(ChatWindow::DccPanel);
 
   dccListView=new KListView(this,"dcc_control_panel");
