@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: inputfilter.cpp,v 1.29 2003/02/02 23:41:33 eisfuchs Exp $
+  $Id: inputfilter.cpp,v 1.34 2003/02/23 18:09:27 eisfuchs Exp $
 */
 
 #include <qstringlist.h>
@@ -24,7 +24,7 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #else
-#define VERSION 0.4
+#define VERSION 0.10
 #endif
 
 #include "inputfilter.h"
@@ -32,6 +32,10 @@
 #include "errorcodes.h"
 #include "konversationapplication.h"
 
+#if QT_VERSION < 0x030100
+#include "main.h"
+#endif
+
 InputFilter::InputFilter()
 {
   kdDebug() << "InputFilter::InputFilter()" << endl;
@@ -122,6 +126,16 @@ void InputFilter::parseClientCommand(QString& prefix,QString& command,QStringLis
           if(!isIgnore(prefix,Ignore::Channel))
             server->appendActionToChannel(parameterList[0],sourceNick,ctcpArgument);
         }
+        // Answer ping requests
+        else if(ctcpCommand=="ping")
+        {
+          if(!isIgnore(prefix,Ignore::CTCP))
+          {
+            server->appendStatusMessage(i18n("CTCP"),i18n("Received CTCP-PING request from %1 to channel %2, sending answer.").arg(sourceNick).arg(parameterList[0]));
+            server->ctcpReply(sourceNick,QString("PING %1").arg(ctcpArgument));
+          }
+        }
+
         // No known CTCP request, give a general message
         else
         {
@@ -196,7 +210,16 @@ void InputFilter::parseClientCommand(QString& prefix,QString& command,QStringLis
           if(!isIgnore(prefix,Ignore::CTCP))
           {
             server->appendStatusMessage(i18n("CTCP"),i18n("Received Version request from %1.").arg(sourceNick));
-            server->ctcpReply(sourceNick,QString("VERSION Konversation %1 (C)2002 Dario Abatianni and Matthias Gierlings").arg(VERSION));
+            server->ctcpReply(sourceNick,QString("VERSION Konversation %1 (C)2002-2003 Dario Abatianni and Matthias Gierlings").arg(VERSION));
+          }
+        }
+        // Answer ping requests
+        else if(ctcpCommand=="ping")
+        {
+          if(!isIgnore(prefix,Ignore::CTCP))
+          {
+            server->appendStatusMessage(i18n("CTCP"),i18n("Received CTCP-PING request from %1, sending answer.").arg(sourceNick));
+            server->ctcpReply(sourceNick,QString("PING %1").arg(ctcpArgument));
           }
         }
         // No known CTCP request, give a general message
@@ -240,7 +263,22 @@ void InputFilter::parseClientCommand(QString& prefix,QString& command,QStringLis
           QString ctcp(trailing.mid(1,trailing.length()-2));
           QString replyReason(ctcp.section(' ',0,0));
           QString reply(ctcp.section(' ',1));
-          server->appendStatusMessage(i18n("CTCP"),i18n("Received CTCP-%1 reply from %2: %3").arg(replyReason).arg(sourceNick).arg(reply));
+
+          // pong reply, calculate turnaround time
+          if(replyReason.lower()=="ping")
+          {
+#if QT_VERSION < 0x030100
+            int dateArrived=toTime_t(QDateTime::currentDateTime());
+#else
+            int dateArrived=QDateTime::currentDateTime().toTime_t();
+#endif
+            int dateSent=reply.toInt();
+            
+            server->appendStatusMessage(i18n("CTCP"),i18n("Received CTCP-PING reply from %1: %2 seconds").arg(sourceNick).arg(dateArrived-dateSent));
+          }
+          // all other ctcp replies get a general message
+          else
+            server->appendStatusMessage(i18n("CTCP"),i18n("Received CTCP-%1 reply from %2: %3").arg(replyReason).arg(sourceNick).arg(reply));
         }
         // No, so it was a normal notice
         else
