@@ -11,17 +11,17 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: konversationapplication.cpp,v 1.43 2003/02/05 21:53:09 eisfuchs Exp $
+  $Id: konversationapplication.cpp,v 1.52 2003/02/20 17:00:59 eisfuchs Exp $
 */
 
 #include <kdebug.h>
 
-#include <qvaluelist.h>
+#include <qregexp.h>
 
 #include "konversationapplication.h"
 #include "serverwindow.h"
 
-/* include static variables */
+// include static variables
 Preferences KonversationApplication::preferences;
 QStringList KonversationApplication::urlList;
 
@@ -30,11 +30,10 @@ KonversationApplication::KonversationApplication()
   kdDebug() << "KonversationApplication::KonversationApplication()" << endl;
 
   prefsDialog=0;
-  
+
   preferences.setTextFont(font());
   preferences.setListFont(font());
 
-  config=new KSimpleConfig("konversationrc");
   readOptions();
 
   // handle autoconnect on startup
@@ -72,15 +71,6 @@ KonversationApplication::~KonversationApplication()
 {
   kdDebug() << "KonversationApplication::~KonversationApplication()" << endl;
   saveOptions(false);
-
-/*
-  kdDebug() << "Deleting Server list ..." << endl;
-  while(serverList.count())
-  {
-    kdDebug() << "deleted" << endl;
-    delete serverList.first();
-  }
-*/
 }
 
 void KonversationApplication::connectToServer(int id)
@@ -101,7 +91,7 @@ void KonversationApplication::connectToAnotherServer(int id)
 
   ServerEntry* chosenServer=preferences.getServerEntryById(id);
 
-  /* Check if a server window with same name and port is already open */
+  // Check if a server window with same name and port is already open
   Server* newServer=serverList.first();
   while(newServer)
   {
@@ -123,7 +113,7 @@ void KonversationApplication::connectToAnotherServer(int id)
 
     newServer=serverList.next();
   }
-  /* We came this far, so generate a new server */
+  // We came this far, so generate a new server
   newServer=new Server(id);
   serverList.append(newServer);
   connect(newServer->getServerWindow(),SIGNAL(prefsChanged()),this,SLOT(saveOptions()));
@@ -141,6 +131,7 @@ void KonversationApplication::readOptions()
 {
   kdDebug() << "KonversationApplication::readOptions()" << endl;
 
+  KConfig* config=kapp->config();
   // Read configuration and provide the default values
   config->setGroup("General Options");
 
@@ -166,13 +157,13 @@ void KonversationApplication::readOptions()
   preferences.setNicknameSize(config->readSizeEntry("NicknameGeometry"));
   preferences.setColorConfigurationSize(config->readSizeEntry("ColorConfigurationGeometry"));
 
-  // Reasons
-  QString reason;
-  reason=config->readEntry("PartReason","");
-  if(reason!="") preferences.setPartReason(reason);
-  reason=config->readEntry("KickReason","");
-  if(reason!="") preferences.setKickReason(reason);
+  // Double click actions
+  preferences.setChannelDoubleClickAction(config->readEntry("ChannelDoubleClickAction",preferences.getChannelDoubleClickAction()));
+  preferences.setNotifyDoubleClickAction(config->readEntry("NotifyDoubleClickAction",preferences.getNotifyDoubleClickAction()));
 
+  // Beep
+  preferences.setBeep(config->readBoolEntry("Beep",preferences.getBeep()));
+  
   // Appearance
   config->setGroup("Appearance");
   // Fonts
@@ -184,6 +175,10 @@ void KonversationApplication::readOptions()
   preferences.setShowModeButtons(config->readBoolEntry("ShowModeButtons",preferences.getShowModeButtons()));
   preferences.setCodec(config->readEntry("Codec",preferences.getCodec()));
 
+  preferences.setUseSpacing(config->readBoolEntry("UseSpacing",preferences.getUseSpacing()));
+  preferences.setSpacing(config->readNumEntry("Spacing",preferences.getSpacing()));
+  preferences.setMargin(config->readNumEntry("Margin",preferences.getMargin()));
+
   QValueList<int> sizes;
   QString sizesString=config->readEntry("ChannelSplitter","10,1");
   sizes.append(sizesString.section(',',0,0).toInt());
@@ -209,18 +204,54 @@ void KonversationApplication::readOptions()
   preferences.setVoiceLedColor(config->readNumEntry("VoiceColor",preferences.getVoiceLedColor()));
   preferences.setNoRightsLedColor(config->readNumEntry("NoRightsColor",preferences.getNoRightsLedColor()));
 
-  // User identity
-  config->setGroup("User Identity");
-  preferences.ident=config->readEntry("Ident",preferences.ident);
-  preferences.realname=config->readEntry("Realname",preferences.realname);
+  // Identity list
+  QStringList identityList=config->groupList().grep(QRegExp("Identity [0-9]+"));
+  if(identityList.count())
+  {
+    preferences.clearIdentityList();
 
-  QString nickList=config->readEntry("Nicknames",preferences.getNicknameList().join(","));
-  preferences.setNicknameList(QStringList::split(",",nickList));
+    for(unsigned int index=0;index<identityList.count();index++)
+    {
+//      kdDebug() << "Reading identity " << identityList[index] << endl;
+      config->setGroup(identityList[index]);
 
-  preferences.setShowAwayMessage(config->readBoolEntry("ShowAwayMessage",preferences.getShowAwayMessage()));
-  preferences.setAwayMessage(config->readEntry("AwayMessage",preferences.getAwayMessage()));
-  preferences.setUnAwayMessage(config->readEntry("UnAwayMessage",preferences.getUnAwayMessage()));
+      Identity* newIdentity=new Identity();
+      newIdentity->setName(config->readEntry("Name"));
 
+      newIdentity->setIdent(config->readEntry("Ident"));
+      newIdentity->setRealName(config->readEntry("Realname"));
+
+      QString nickList=config->readEntry("Nicknames");
+      newIdentity->setNicknameList(QStringList::split(",",nickList));
+
+      newIdentity->setShowAwayMessage(config->readBoolEntry("ShowAwayMessage"));
+      newIdentity->setAwayMessage(config->readEntry("AwayMessage"));
+      newIdentity->setReturnMessage(config->readEntry("ReturnMessage"));
+
+      newIdentity->setPartReason(config->readEntry("PartReason"));
+      newIdentity->setKickReason(config->readEntry("KickReason"));
+
+      preferences.addIdentity(newIdentity);
+    } // endfor
+  }
+  else
+  {
+    kdDebug() << "Importing pre 0.10 identity settings ..." << endl;
+
+    // Default user identity for pre 0.10 preferences files
+    config->setGroup("User Identity");
+    preferences.setIdent(config->readEntry("Ident",preferences.getIdent()));
+    preferences.setRealName(config->readEntry("Realname",preferences.getRealName()));
+
+    QString nickList=config->readEntry("Nicknames",preferences.getNicknameList().join(","));
+    preferences.setNicknameList(QStringList::split(",",nickList));
+
+    preferences.setShowAwayMessage(config->readBoolEntry("ShowAwayMessage",preferences.getShowAwayMessage()));
+    preferences.setAwayMessage(config->readEntry("AwayMessage",preferences.getAwayMessage()));
+    preferences.setUnAwayMessage(config->readEntry("UnAwayMessage",preferences.getUnAwayMessage()));
+
+    config->deleteGroup("User Identity");
+  }
   // Notify Settings and list
   config->setGroup("Notify List");
   preferences.setNotifyDelay(config->readNumEntry("NotifyDelay",20));
@@ -328,6 +359,8 @@ void KonversationApplication::saveOptions(bool updateGUI)
 {
   kdDebug() << "KonversationApplication::saveOptions()" << endl;
 
+  KConfig* config=kapp->config();
+
   config->setGroup("General Options");
 
   config->writeEntry("CommandChar",preferences.getCommandChar());
@@ -348,9 +381,11 @@ void KonversationApplication::saveOptions(bool updateGUI)
 
   config->writeEntry("ServerWindowStatusBarStatus",preferences.serverWindowStatusBarStatus);
 
-  config->writeEntry("PartReason",preferences.getPartReason());
-  config->writeEntry("KickReason",preferences.getKickReason());
+  config->writeEntry("ChannelDoubleClickAction",preferences.getChannelDoubleClickAction());
+  config->writeEntry("NotifyDoubleClickAction",preferences.getNotifyDoubleClickAction());
 
+  config->writeEntry("Beep",preferences.getBeep());
+  
   config->setGroup("Appearance");
 
   config->writeEntry("TextFont",preferences.getTextFont().toString());
@@ -361,6 +396,10 @@ void KonversationApplication::saveOptions(bool updateGUI)
   config->writeEntry("ShowModeButtons",preferences.getShowModeButtons());
   config->writeEntry("Codec",preferences.getCodec());
 
+  config->writeEntry("UseSpacing",preferences.getUseSpacing());
+  config->writeEntry("Spacing",preferences.getSpacing());
+  config->writeEntry("Margin",preferences.getMargin());
+  
   QString sizesString(QString::number(preferences.getChannelSplitter()[0])+","+QString::number(preferences.getChannelSplitter()[1]));
   config->writeEntry("ChannelSplitter",sizesString);
 
@@ -381,14 +420,33 @@ void KonversationApplication::saveOptions(bool updateGUI)
   config->writeEntry("VoiceColor", preferences.getVoiceLedColor());
   config->writeEntry("NoRightsColor", preferences.getNoRightsLedColor());
 
-  config->setGroup("User Identity");
+  // Clean up identity list
+  QStringList identities=config->groupList().grep(QRegExp("Identity [0-9]+"));
+  if(identities.count())
+  {
+    // remove old identity list from preferences file to keep numbering under control
+    for(unsigned int index=0;index<identities.count();index++)
+      config->deleteGroup(identities[index]);
+  }
 
-  config->writeEntry("Ident",preferences.ident);
-  config->writeEntry("Realname",preferences.realname);
-  config->writeEntry("Nicknames",preferences.getNicknameList());
-  config->writeEntry("ShowAwayMessage",preferences.getShowAwayMessage());
-  config->writeEntry("AwayMessage",preferences.getAwayMessage());
-  config->writeEntry("UnAwayMessage",preferences.getUnAwayMessage());
+  QPtrList<Identity> identityList=preferences.getIdentityList();
+  for(unsigned int index=0;index<identityList.count();index++)
+  {
+//    kdDebug() << "Writing identity " << index << endl;
+
+    Identity* identity=identityList.at(index);
+    config->setGroup(QString("Identity %1").arg(index));
+
+    config->writeEntry("Name",identity->getName());
+    config->writeEntry("Ident",identity->getIdent());
+    config->writeEntry("Realname",identity->getRealName());
+    config->writeEntry("Nicknames",identity->getNicknameList());
+    config->writeEntry("ShowAwayMessage",identity->getShowAwayMessage());
+    config->writeEntry("AwayMessage",identity->getAwayMessage());
+    config->writeEntry("ReturnMessage",identity->getReturnMessage());
+    config->writeEntry("PartReason",identity->getPartReason());
+    config->writeEntry("KickReason",identity->getKickReason());
+  } // endfor
 
   config->setGroup("Notify List");
 
@@ -522,7 +580,7 @@ void KonversationApplication::openPrefsDialog()
 
 void KonversationApplication::syncPrefs()
 {
-  config->sync();
+  kapp->config()->sync();
 }
 
 void KonversationApplication::closePrefsDialog()
