@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: konversationapplication.h,v 1.7 2003/02/05 16:43:54 eisfuchs Exp $
+  $Id: konversationapplication.h,v 1.8 2003/02/20 17:01:01 eisfuchs Exp $
 */
 
 #ifndef KONVERSATIONAPPLICATION_H
@@ -34,7 +34,8 @@ class KonversationApplication : public KApplication
   public:
     static Preferences preferences;
 
-    /* URL-Catcher */
+    // URL-Catcher
+    // TODO: Provide a list of seen URLs
     static QStringList urlList;
     static void storeURL(QString& url);
 
@@ -55,7 +56,6 @@ class KonversationApplication : public KApplication
 
   protected:
     QPtrList<Server> serverList;
-    KSimpleConfig* config;
     PrefsDialog* prefsDialog;
 };
 
