@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: ledtabwidget.h,v 1.6 2002/11/18 17:49:51 eisfuchs Exp $
+  $Id: ledtabwidget.h,v 1.7 2003/02/17 14:00:21 eisfuchs Exp $
 */
 
 #ifndef LEDTABWIDGET_H
@@ -40,9 +40,11 @@ class LedTabWidget : public QTabWidget
 
   signals:
     void currentChanged(QWidget* view);
+    void closeTab(QWidget* view);
 
   protected slots:
     void tabSelected(int id);
+    void tabClosed(int id);
 
   protected:
     LedTabBar* tabBar();
