@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: nickchangedialog.h,v 1.2 2002/07/20 15:18:19 eisfuchs Exp $
+  $Id: nickchangedialog.h,v 1.3 2003/02/10 21:30:29 eisfuchs Exp $
 */
 
 
@@ -32,7 +32,7 @@ class NickChangeDialog : public KDialogBase
   Q_OBJECT
 
   public: 
-    NickChangeDialog(QWidget* parent,QString currentNick,QStringList nickList,QSize initialSize);
+    NickChangeDialog(QWidget* parent,QString currentNick,const QStringList& nickList,QSize initialSize);
     ~NickChangeDialog();
 
   signals:
