@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: outputfilter.cpp,v 1.31 2003/02/06 08:52:13 eisfuchs Exp $
+  $Id: outputfilter.cpp,v 1.38 2003/02/23 18:09:27 eisfuchs Exp $
 */
 
 #include <qstringlist.h>
@@ -25,6 +25,10 @@
 #include "konversationapplication.h"
 #include "outputfilter.h"
 
+#if QT_VERSION < 0x030100
+#include "main.h"
+#endif
+
 OutputFilter::OutputFilter()
 {
 }
@@ -33,12 +37,10 @@ OutputFilter::~OutputFilter()
 {
 }
 
-QString& OutputFilter::parse(const QString& myNick,const QString& inputLine,const QString& name)
+QString& OutputFilter::parse(const QString& myNick,const QString& originalLine,const QString& name)
 {
   setCommandChar();
 
-  QString line=inputLine.lower();
-
   toServer="";
   output="";
   type="";
@@ -48,6 +50,15 @@ QString& OutputFilter::parse(const QString& myNick,const QString& inputLine,cons
   program=false;
   command=false;
   query=false;
+  
+  QString inputLine=originalLine;
+
+  // replace placeholders
+  inputLine.replace(QRegExp("%%"),"%\x01");  // make sure to protect double %%
+  inputLine.replace(QRegExp("%G"),"\x07");   // replace %G with ASCII BEL 0x07
+  inputLine.replace(QRegExp("%\x01"),"%");   // restore double %% as single %
+
+  QString line=inputLine.lower();
 
   // Action?
   if(line.startsWith(commandChar+"me ") && destination!="")
@@ -172,7 +183,7 @@ void OutputFilter::parseKick(QString parameter)
       // get kick reason (if any)
       QString reason=parameter.mid(victim.length()+1);
       // if no reason given, take default reason
-      if(reason=="") reason=KonversationApplication::preferences.getKickReason();
+      if(reason=="") reason=identity.getKickReason();
       toServer="KICK "+destination+" "+victim+" :"+reason;
     }
   }
@@ -190,7 +201,7 @@ void OutputFilter::parsePart(QString parameter)
   if(parameter=="")
   {
     // But only if we actually are in a channel
-    if(isAChannel(destination)) toServer="PART "+destination+" :"+KonversationApplication::preferences.getPartReason();
+    if(isAChannel(destination)) toServer="PART "+destination+" :"+identity.getPartReason();
     else
     {
       type=i18n("Error");
@@ -208,7 +219,7 @@ void OutputFilter::parsePart(QString parameter)
       // get part reason (if any)
       QString reason=parameter.mid(channel.length()+1);
       // if no reason given, take default reason
-      if(reason=="") reason=KonversationApplication::preferences.getPartReason();
+      if(reason=="") reason=identity.getPartReason();
       toServer="PART "+channel+" :"+reason;
     }
     // part this channel with a given reason
@@ -271,16 +282,19 @@ void OutputFilter::parseAway(QString reason)
 {
   if(reason=="")
   {
-    if(KonversationApplication::preferences.getShowAwayMessage())
-      sendToAllChannels(KonversationApplication::preferences.getUnAwayMessage());
+    if(identity.getShowAwayMessage())
+      sendToAllChannels(identity.getReturnMessage());
 
     emit unAway();
     toServer="AWAY";
   }
   else
   {
-    if(KonversationApplication::preferences.getShowAwayMessage())
-      sendToAllChannels(KonversationApplication::preferences.getAwayMessage().replace(QRegExp("%s",false),reason));
+    if(identity.getShowAwayMessage())
+    {
+      QString message=identity.getAwayMessage();
+      sendToAllChannels(message.replace(QRegExp("%s",false),reason));
+    }
 
     emit away();
     toServer="AWAY :"+reason;
@@ -292,7 +306,7 @@ void OutputFilter::parseAway(QString reason)
 void OutputFilter::parseQuit(QString reason)
 {
   // if no reason given, take default reason
-  if(reason=="") reason=KonversationApplication::preferences.getPartReason();
+  if(reason=="") reason=identity.getPartReason();
   toServer="QUIT :"+reason;
 }
 
@@ -352,12 +366,25 @@ void OutputFilter::parseSMsg(QString parameter)
 
 void OutputFilter::parseCtcp(QString parameter)
 {
-  QString recipient=parameter.left(parameter.find(" "));
-  QString message=parameter.mid(recipient.length()+1);
+  QString recipient=parameter.section(' ',0,0);  // who is the recipient?
+  QString request=parameter.section(' ',1,1);    // what is the first word of the ctcp?
+  QString message=parameter.section(' ',1);      // what is the complete ctcp command?
 
-  toServer=QString("PRIVMSG "+recipient+" :"+'\x01'+message+'\x01');
-  
-  output=i18n("Sending CTCP-%1 request to %2").arg(message).arg(recipient);
+  if(request.lower()=="ping")
+  {
+#if QT_VERSION < 0x030100
+    unsigned int time_t=toTime_t(QDateTime::currentDateTime());
+#else
+    unsigned int time_t=QDateTime::currentDateTime().toTime_t();
+#endif
+    toServer=QString("PRIVMSG "+recipient+" :\x01PING %1\x01").arg(time_t);
+    output=i18n("Sending CTCP-PING request to %1").arg(recipient);
+  }
+  else
+  {
+    toServer=QString("PRIVMSG "+recipient+" :"+'\x01'+message+'\x01');
+    output=i18n("Sending CTCP-%1 request to %2").arg(message).arg(recipient);
+  }
   type=i18n("CTCP");
   program=true;
 }
@@ -533,6 +560,7 @@ bool OutputFilter::isProgram() { return program; };
 bool OutputFilter::isQuery() { return query; };
 
 void OutputFilter::setCommandChar() { commandChar=KonversationApplication::preferences.getCommandChar(); }
+void OutputFilter::setIdentity(const Identity& newIdentity) { identity=newIdentity; }
 
 QString& OutputFilter::getOutput() { return output; };
 QString& OutputFilter::getServerOutput() { return toServer; };
