@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: outputfilter.h,v 1.20 2003/02/05 20:16:56 eisfuchs Exp $
+  $Id: outputfilter.h,v 1.21 2003/02/10 16:39:47 eisfuchs Exp $
 */
 
 #ifndef OUTPUTFILTER_H
@@ -20,6 +20,8 @@
 #include <qobject.h>
 #include <qstring.h>
 
+#include "identity.h"
+
 /*
   @author Dario Abatianni
 */
@@ -58,6 +60,7 @@ class OutputFilter : public QObject
 
   public slots:
     void setCommandChar();
+    void setIdentity(const Identity& newIdentity);
 
   protected:
     QString output;
@@ -66,6 +69,7 @@ class OutputFilter : public QObject
     QString destination;
 
     QString commandChar;
+    Identity identity;
 
     // message types
     bool action;
