@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: preferences.cpp,v 1.40 2003/02/05 20:16:56 eisfuchs Exp $
+  $Id: preferences.cpp,v 1.48 2003/02/17 20:03:00 eisfuchs Exp $
 */
 
 #include <ktoolbar.h>
@@ -31,8 +31,25 @@ Preferences::Preferences()
   serverWindowStatusBarStatus=true;
   serverList.setAutoDelete(true);
 
-  ident="konversation";
-  realname="Konversation User";
+  // create default identity
+  Identity* identity=new Identity();
+  identity->setName(i18n("Default identity"));
+  addIdentity(identity);
+
+  setIdent("konversation");
+  setRealName("Konversation User");
+
+  setNickname(0,"KonvIRC");
+  setNickname(1,"_KonvIRC");
+  setNickname(2,"KonvIRC_");
+  setNickname(3,"_KonvIRC_");
+
+  setPartReason("Konversation terminated!");
+  setKickReason("User terminated!");
+
+  setShowAwayMessage(false);
+  setAwayMessage("/me is away: %s");
+  setUnAwayMessage("/me is back.");
 
   setChannelMessageColor("000000");
   setQueryMessageColor("0000ff");
@@ -46,16 +63,7 @@ Preferences::Preferences()
   setNickCompleteSuffixStart(": ");
   setNickCompleteSuffixMiddle(" ");
 
-  setShowAwayMessage(false);
-  setAwayMessage("/me is away: %s");
-  setUnAwayMessage("/me is back.");
-
-  nicknameList.append("KonvIRC");
-  nicknameList.append("_KonvIRC");
-  nicknameList.append("KonvIRC_");
-  nicknameList.append("_KonvIRC_");
-
-  addServer("IRCNet,irc.kde.org,6667,,#kde-users,,0");
+  addServer("IRCNet,irc.kde.org,6667,,#kde-users,,0,");
 
   buttonList.append("Op,/OP %u%n");
   buttonList.append("DeOp,/DEOP %u%n");
@@ -70,18 +78,18 @@ Preferences::Preferences()
   setShowModeButtons(true);
   setShowServerList(true);
 
+  setUseSpacing(false);
+  setSpacing(2);
+  setMargin(3);
+
   channelSplitter.append(10);
   channelSplitter.append(1);
   
-  setPartReason("Konversation terminated!");
-  setKickReason("User terminated!");
-
-  KStandardDirs kstddir;
-
   setAutoReconnect(true);
   setAutoRejoin(true);
 
   setFixedMOTD(true);
+  setBeep(false);
 
   setDccPath("");
   setDccAddPartner(true);
@@ -90,7 +98,9 @@ Preferences::Preferences()
   setDccBufferSize(1024);
   setDccRollback(1024);
 
+  KStandardDirs kstddir;
   setLogPath(kstddir.saveLocation("data","konversation/logs"));
+
   setLog(true);
   setLowerLog(true);
   setLogFollowsNick(true);
@@ -116,6 +126,8 @@ Preferences::Preferences()
   setCodec(QTextCodec::codecForLocale()->name());
 
   setCommandChar("/");
+  setChannelDoubleClickAction("/WHOIS %u%n");
+  setNotifyDoubleClickAction("/WHOIS %u%n");
 }
 
 Preferences::~Preferences()
@@ -263,15 +275,18 @@ bool Preferences::getDccAutoGet() { return dccAutoGet; }
 void Preferences::setDccPath(QString path) { dccPath=path; }
 QString Preferences::getDccPath() { return dccPath; }
 
-void Preferences::setFixedMOTD(bool fixed) { fixedMOTD=fixed; }
+void Preferences::setFixedMOTD(bool state) { fixedMOTD=state; }
 bool Preferences::getFixedMOTD() { return fixedMOTD; }
 
-void Preferences::setAutoReconnect(bool on) { autoReconnect=on; }
+void Preferences::setAutoReconnect(bool state) { autoReconnect=state; }
 bool Preferences::getAutoReconnect() { return autoReconnect; }
 
-void Preferences::setAutoRejoin(bool on) { autoRejoin=on; }
+void Preferences::setAutoRejoin(bool state) { autoRejoin=state; }
 bool Preferences::getAutoRejoin() { return autoRejoin; }
 
+void Preferences::setBeep(bool state) { beep=state; }
+bool Preferences::getBeep() { return beep; }
+
 int Preferences::getNotifyDelay() { return notifyDelay; }
 void Preferences::setNotifyDelay(int delay) { notifyDelay=delay; }
 bool Preferences::getUseNotify() { return useNotify; }
@@ -282,27 +297,56 @@ QString Preferences::getNotifyString() { return notifyList.join(" "); }
 
 QStringList Preferences::getButtonList() { return buttonList; }
 
-QString Preferences::getPartReason() { return partReason; }
-void Preferences::setPartReason(QString newReason) { partReason=newReason; }
+// Default identity functions
+void Preferences::addIdentity(Identity* identity) { identityList.append(identity); }
+void Preferences::clearIdentityList() { identityList.clear(); }
+QPtrList<Identity> Preferences::getIdentityList() { return identityList; }
 
-QString Preferences::getKickReason() { return kickReason; }
-void Preferences::setKickReason(QString newReason) { kickReason=newReason; }
+const Identity& Preferences::getIdentityByName(const QString& name)
+{
+  kdDebug() << "Requested Identity: " << name << endl;
 
-void Preferences::setShowAwayMessage(bool state) { showAwayMessage=state; }
-bool Preferences::getShowAwayMessage() { return showAwayMessage; }
+  QPtrList<Identity> identities=getIdentityList();
+  Identity* identity=identities.first();
+  while(identity)
+  {
+    kdDebug() << "Trying " << identity->getName() << endl;
+    if(identity->getName()==name) return *identity;
+    identity=identities.next();
+  }
+  // no matching identity found, return default identity
+  identity=identities.first();
+  kdDebug() << "Default Identity returned" << endl;
+  return *identity;
+}
 
-QString Preferences::getAwayMessage() { return awayMessage; }
-void Preferences::setAwayMessage(QString newMessage) { awayMessage=newMessage; }
-QString Preferences::getUnAwayMessage() { return unAwayMessage; }
-void Preferences::setUnAwayMessage(QString newMessage) { unAwayMessage=newMessage; }
+QString Preferences::getRealName() { return identityList.at(0)->getRealName(); }
+void Preferences::setRealName(QString name) { identityList.at(0)->setRealName(name); }
+
+QString Preferences::getIdent() { return identityList.at(0)->getIdent(); }
+void Preferences::setIdent(QString ident) { identityList.at(0)->setIdent(ident); }
+
+QString Preferences::getPartReason() { return identityList.at(0)->getPartReason(); }
+void Preferences::setPartReason(QString newReason) { identityList.at(0)->setPartReason(newReason); }
+
+QString Preferences::getKickReason() { return identityList.at(0)->getKickReason(); }
+void Preferences::setKickReason(QString newReason) { identityList.at(0)->setKickReason(newReason); }
+
+bool Preferences::getShowAwayMessage() { return identityList.at(0)->getShowAwayMessage(); }
+void Preferences::setShowAwayMessage(bool state) { identityList.at(0)->setShowAwayMessage(state); }
+
+QString Preferences::getAwayMessage() { return identityList.at(0)->getAwayMessage(); }
+void Preferences::setAwayMessage(QString newMessage) { identityList.at(0)->setAwayMessage(newMessage); }
+QString Preferences::getUnAwayMessage() { return identityList.at(0)->getReturnMessage(); }
+void Preferences::setUnAwayMessage(QString newMessage) { identityList.at(0)->setReturnMessage(newMessage); }
 
 void Preferences::clearIgnoreList() { ignoreList.clear(); }
 QPtrList<Ignore> Preferences::getIgnoreList() { return ignoreList; }
 
-QString Preferences::getNickname(int index) { return nicknameList[index]; }
-QStringList Preferences::getNicknameList() { return nicknameList; }
-void Preferences::setNickname(int index,QString newName) { nicknameList[index]=newName; }
-void Preferences::setNicknameList(QStringList newList) { nicknameList=newList; }
+QString Preferences::getNickname(int index) { return identityList.at(0)->getNickname(index); }
+QStringList Preferences::getNicknameList() { return identityList.at(0)->getNicknameList(); }
+void Preferences::setNickname(int index,QString newName) { identityList.at(0)->setNickname(index,newName); }
+void Preferences::setNicknameList(QStringList newList) { identityList.at(0)->setNicknameList(newList); }
 
 void Preferences::setBlinkingTabs(bool blink) { blinkingTabs=blink; }
 bool Preferences::getBlinkingTabs() { return blinkingTabs; }
@@ -406,4 +450,18 @@ QValueList<int> Preferences::getChannelSplitter() { return channelSplitter; }
 
 void Preferences::setCodec(QString newCodec) { codec=newCodec; }
 QString Preferences::getCodec() { return codec; }
+
+void Preferences::setChannelDoubleClickAction(QString action) { channelDoubleClickAction=action; }
+QString Preferences::getChannelDoubleClickAction() { return channelDoubleClickAction; }
+
+void Preferences::setNotifyDoubleClickAction(QString action) { notifyDoubleClickAction=action; }
+QString Preferences::getNotifyDoubleClickAction() { return notifyDoubleClickAction; }
+
+void Preferences::setUseSpacing(bool state) { useSpacing=state; }
+bool Preferences::getUseSpacing() { return useSpacing; }
+void Preferences::setSpacing(int newSpacing) { spacing=newSpacing; }
+int Preferences::getSpacing() { return spacing; }
+void Preferences::setMargin(int newMargin) { margin=newMargin; }
+int Preferences::getMargin() { return margin; }
+
 #include "preferences.moc"
