@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: preferences.h,v 1.37 2003/02/05 20:16:56 eisfuchs Exp $
+  $Id: preferences.h,v 1.42 2003/02/16 20:03:00 eisfuchs Exp $
 */
 
 #ifndef PREFERENCES_H
@@ -27,6 +27,7 @@
 #include "serverentry.h"
 #include "ignore.h"
 #include "highlight.h"
+#include "identity.h"
 
 /*
   @author Dario Abatianni
@@ -64,9 +65,11 @@ class Preferences : public QObject
     QValueList<int> getAutoConnectServerIDs();
 
     bool getAutoReconnect();
+    void setAutoReconnect(bool state);
     bool getAutoRejoin();
-    void setAutoReconnect(bool on);
-    void setAutoRejoin(bool on);
+    void setAutoRejoin(bool state);
+    bool getBeep();
+    void setBeep(bool state);
 
     void clearServerList();
     void changeServerProperty(int id,int property,const QString& value);
@@ -149,6 +152,17 @@ class Preferences : public QObject
     QPtrList<Ignore> getIgnoreList();
     void setIgnoreList(QPtrList<Ignore> newList);
 
+    void addIdentity(Identity* identity);
+    void clearIdentityList();
+    QPtrList<Identity> getIdentityList();
+    const Identity& getIdentityByName(const QString& name);
+
+    QString getIdent();
+    void setIdent(QString ident);
+
+    QString getRealName();
+    void setRealName(QString name);
+
     QString getPartReason();
     void setPartReason(QString newReason);
 
@@ -232,8 +246,18 @@ class Preferences : public QObject
     void setChannelSplitter(QValueList<int> sizes);
     QValueList<int> getChannelSplitter();
 
-    QString ident;
-    QString realname;
+    void setChannelDoubleClickAction(QString action);
+    QString getChannelDoubleClickAction();
+
+    void setNotifyDoubleClickAction(QString action);
+    QString getNotifyDoubleClickAction();
+
+    void setUseSpacing(bool state);
+    bool getUseSpacing();
+    void setSpacing(int newSpacing);
+    int getSpacing();
+    void setMargin(int newMargin);
+    int getMargin();
 
   signals:
     void requestServerConnection(int number);
@@ -249,6 +273,7 @@ class Preferences : public QObject
     bool bringToFront;      // Do we want to see newly created tabs immediately?
 
     bool fixedMOTD;
+    bool beep;
 
     bool dccAddPartner;
     bool dccCreateFolder;   // create folders for each DCC partner?
@@ -265,10 +290,6 @@ class Preferences : public QObject
     int voiceLedColor;
     int noRightsLedColor;
     bool useNotify;
-    
-    bool showAwayMessage;
-    QString awayMessage;
-    QString unAwayMessage;
 
     bool timestamping;
     QString timestampFormat;
@@ -285,6 +306,9 @@ class Preferences : public QObject
     QString nickCompleteSuffixStart;
     QString nickCompleteSuffixMiddle;
 
+    QString channelDoubleClickAction;
+    QString notifyDoubleClickAction;
+
     // rewrite these to use an array or list of some sort
     QString channelMessageColor;
     QString queryMessageColor;
@@ -306,10 +330,14 @@ class Preferences : public QObject
     QSize nicknameSize;
     QSize colorConfigurationSize;
 
+    bool useSpacing;
+    int spacing;
+    int margin;
+
     QFont textFont;
     QFont listFont;
-    
-    QList<ServerEntry> serverList;
+
+    QPtrList<ServerEntry> serverList;
     QPtrList<Highlight> hilightList;
 
     bool hilightNick;
@@ -321,10 +349,7 @@ class Preferences : public QObject
 
     QPtrList<Ignore> ignoreList;
 
-    QStringList nicknameList;
-
-    QString partReason;
-    QString kickReason;
+    QPtrList<Identity> identityList;
 
     QString codec;
 };
