@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: prefsdialog.cpp,v 1.16 2003/02/02 21:32:46 eisfuchs Exp $
+  $Id: prefsdialog.cpp,v 1.17 2003/02/23 16:51:15 eisfuchs Exp $
 */
 
 #include <qlabel.h>
@@ -28,7 +28,7 @@
 #include "prefspageappearance.h"
 #include "prefspagelog.h"
 #include "prefspagedccsettings.h"
-#include "prefspagescripts.h"
+// #include "prefspagescripts.h"
 #include "serverlistitem.h"
 #include "editserverdialog.h"
 #include "konversationapplication.h"
@@ -65,7 +65,7 @@ PrefsDialog::PrefsDialog(Preferences* preferences,bool noServer) :
 /*  PrefsPage* dccSettingsPage= */ new PrefsPageDccSettings(dccSettingsPane, preferences);
   // Add scripts page
   // TODO: Uncomment this again when it's ready to go
-  //  PrefsPage* scriptsPage= new PrefsPageScripts(scriptsPane, preferences);
+//    PrefsPage* scriptsPage= new PrefsPageScripts(scriptsPane, preferences);
 
   setButtonOKText(i18n("OK"),i18n("Keep changes made to configuration and close the window"));
   setButtonApplyText(i18n("Apply"),i18n("Keep changes made to configuration"));
