@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: prefspageappearance.h,v 1.6 2003/02/02 21:32:46 eisfuchs Exp $
+  $Id: prefspageappearance.h,v 1.8 2003/02/16 20:03:01 eisfuchs Exp $
 */
 
 #ifndef PREFSPAGEAPPEARANCE_H
@@ -19,6 +19,7 @@
 
 #include <qlabel.h>
 #include <qcheckbox.h>
+#include <qspinbox.h>
 
 #include "prefspage.h"
 
@@ -42,10 +43,12 @@ class PrefsPageAppearance : public PrefsPage
     void showModeButtonsChanged(int state);
     void formatChanged(const QString& newFormat);
     void encodingChanged(const QString& newEncoding);
+    void useSpacingChanged(int state);
+    void spacingChanged(int newSpacing);
+    void marginChanged(int newMargin);
 
   protected:
     void updateFonts();
-    QStringList getEncodings();
 
     QLabel* textPreviewLabel;
     QLabel* listPreviewLabel;
@@ -55,6 +58,14 @@ class PrefsPageAppearance : public PrefsPage
     QCheckBox* showModeButtons;
     QLabel* formatLabel;
     QComboBox* timestampFormat;
+
+    QCheckBox* useSpacingCheck;
+
+    QLabel* spacingLabel;
+    QLabel* marginLabel;
+    
+    QSpinBox* spacing;
+    QSpinBox* margin;
 };
 
 #endif
