@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: prefspagedccsettings.cpp,v 1.7 2003/02/06 15:12:02 eisfuchs Exp $
+  $Id: prefspagedccsettings.cpp,v 1.9 2003/02/16 20:03:01 eisfuchs Exp $
 */
 
 #include <qlayout.h>
@@ -148,4 +148,15 @@ void PrefsPageDccSettings::createFolderChanged(int state)
   preferences->setDccCreateFolder(state==2);
 }
 
+QString PrefsPageDccSettings::getExistingDirectory(const QString& startDir,
+                                                   QWidget *parent,
+                                                   const QString& caption)
+{
+  return KFileDialog::getExistingDirectory(
+                                            preferences->getDccPath(),
+                                            0,
+                                            i18n("Select DCC download folder")
+                                          );
+}
+
 #include "prefspagedccsettings.moc"
