@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: prefspagegeneralsettings.h,v 1.4 2002/12/01 13:08:53 eisfuchs Exp $
+  $Id: prefspagegeneralsettings.h,v 1.6 2003/02/15 17:51:22 eisfuchs Exp $
 */
 
 
@@ -36,11 +36,14 @@ class PrefsPageGeneralSettings : public PrefsPage
     void commandCharChanged(const QString& newChar);
     void suffixStartChanged(const QString& newSuffix);
     void suffixMiddleChanged(const QString& newSuffix);
+    void channelActionChanged(const QString& newAction);
+    void notifyActionChanged(const QString& newAction);
     void autoReconnectChanged(int state);
     void autoRejoinChanged(int state);
     void blinkingTabsChanged(int state);
     void bringToFrontChanged(int state);
     void fixedMOTDChanged(int state);
+    void beepChanged(int state);
 };
 
 #endif
