@@ -11,14 +11,14 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: prefspageidentity.cpp,v 1.5 2003/02/05 20:16:57 eisfuchs Exp $
+  $Id: prefspageidentity.cpp,v 1.9 2003/02/10 16:39:48 eisfuchs Exp $
 */
 
 #include <qlayout.h>
-#include <qlabel.h>
-#include <qcheckbox.h>
+#include <qhbox.h>
+#include <qpushbutton.h>
 
-#include <klineedit.h>
+#include <kdebug.h>
 
 #include "prefspageidentity.h"
 
@@ -28,35 +28,60 @@ PrefsPageIdentity::PrefsPageIdentity(QFrame* newParent,Preferences* newPreferenc
   // Add a Layout to the identity pane
   QGridLayout* identityLayout=new QGridLayout(parentFrame,4,4,marginHint(),spacingHint());
 
+  QLabel* identityLabel=new QLabel(i18n("Identity:"),parentFrame);
+  identityCombo=new KComboBox(parentFrame);
+  identityCombo->setEditable(true);
+  identityCombo->setInsertionPolicy(QComboBox::NoInsertion);
+
+  identities=preferences->getIdentityList();
+
+  for(unsigned int index=0;index<identities.count();index++)
+    identityCombo->insertItem(identities.at(index)->getName());
+
   QLabel* realNameLabel=new QLabel(i18n("Real name:"),parentFrame);
-  KLineEdit* realNameInput=new KLineEdit(preferences->realname,parentFrame);
+  realNameInput=new KLineEdit(parentFrame);
 
   QLabel* loginLabel=new QLabel(i18n("Ident:"),parentFrame);
-  KLineEdit* loginInput=new KLineEdit(preferences->ident,parentFrame);
+  loginInput=new KLineEdit(parentFrame);
 
-  QStringList nicknameList=preferences->getNicknameList();
-
-  KLineEdit* nick0=new KLineEdit(nicknameList[0],parentFrame);
-  KLineEdit* nick1=new KLineEdit(nicknameList[1],parentFrame);
-  KLineEdit* nick2=new KLineEdit(nicknameList[2],parentFrame);
-  KLineEdit* nick3=new KLineEdit(nicknameList[3],parentFrame);
+  nick0=new KLineEdit(parentFrame);
+  nick1=new KLineEdit(parentFrame);
+  nick2=new KLineEdit(parentFrame);
+  nick3=new KLineEdit(parentFrame);
 
   QLabel* partLabel=new QLabel(i18n("Part Reason:"),parentFrame);
-  KLineEdit* partInput=new KLineEdit(preferences->getPartReason(),parentFrame);
+  partInput=new KLineEdit(parentFrame);
 
   QLabel* kickLabel=new QLabel(i18n("Kick Reason:"),parentFrame);
-  KLineEdit* kickInput=new KLineEdit(preferences->getKickReason(),parentFrame);
+  kickInput=new KLineEdit(parentFrame);
 
-  QCheckBox* showAwayMessageCheck=new QCheckBox(i18n("Show away messages"),parentFrame,"away_message_check");
-  showAwayMessageCheck->setChecked(preferences->getShowAwayMessage());
+  showAwayMessageCheck=new QCheckBox(i18n("Show away messages"),parentFrame,"away_message_check");
 
   QLabel* awayLabel=new QLabel(i18n("Away message:"),parentFrame);
-  KLineEdit* awayInput=new KLineEdit(preferences->getAwayMessage(),parentFrame);
+  awayInput=new KLineEdit(parentFrame);
 
   QLabel* unAwayLabel=new QLabel(i18n("Return message:"),parentFrame);
-  KLineEdit* unAwayInput=new KLineEdit(preferences->getUnAwayMessage(),parentFrame);
+  unAwayInput=new KLineEdit(parentFrame);
+
+  defaultText=new QLabel(i18n("<qt>This is the default identity used for all servers "
+                              "where no separate identity was selected.</qt>"),
+                              parentFrame);
+
+  QHBox* buttonBox=new QHBox(parentFrame);
+  buttonBox->setSpacing(spacingHint());
+
+  QPushButton* addIdentityButton=new QPushButton(i18n("Add new identity"),buttonBox,"add_identity_button");
+  QPushButton* removeIdentityButton=new QPushButton(i18n("Remove identity"),buttonBox,"remove_identity_button");
+  removeIdentityButton->setEnabled(false);
+  QHBox* spacer=new QHBox(parentFrame);
+
+  // set values for the widgets
+  updateIdentity(0);
 
   int row=0;
+  identityLayout->addWidget(identityLabel,row,0);
+  identityLayout->addMultiCellWidget(identityCombo,row,row,1,3);
+  row++;
   identityLayout->addWidget(realNameLabel,row,0);
   identityLayout->addMultiCellWidget(realNameInput,row,row,1,3);
   row++;
@@ -87,11 +112,11 @@ PrefsPageIdentity::PrefsPageIdentity(QFrame* newParent,Preferences* newPreferenc
   identityLayout->addWidget(unAwayLabel,row,0);
   identityLayout->addMultiCellWidget(unAwayInput,row,row,1,3);
   row++;
-  identityLayout->addMultiCellWidget(new QLabel(i18n(
-                                     "<qt>This is the default identity used for all servers "
-                                     "where no separate identity was selected.</qt>"),
-                                     parentFrame),row,row,0,3);
+  identityLayout->addMultiCellWidget(defaultText,row,row,0,3);
   row++;
+  identityLayout->addMultiCellWidget(buttonBox,row,row,0,3);
+  row++;
+  identityLayout->addMultiCellWidget(spacer,row,row,0,3);
   identityLayout->setRowStretch(row,10);
 
   // Set up signals / slots for identity page
@@ -106,6 +131,9 @@ PrefsPageIdentity::PrefsPageIdentity(QFrame* newParent,Preferences* newPreferenc
   connect(showAwayMessageCheck,SIGNAL (stateChanged(int)),this,SLOT (showAwayMessageChanged(int)) );
   connect(awayInput,SIGNAL (textChanged(const QString&)),this,SLOT (awayMessageChanged(const QString&)) );
   connect(unAwayInput,SIGNAL (textChanged(const QString&)),this,SLOT (unAwayMessageChanged(const QString&)) );
+  connect(identityCombo,SIGNAL (activated(int)),this,SLOT (updateIdentity(int)) );
+  connect(identityCombo,SIGNAL (returnPressed(const QString&)),this,SLOT (renameIdentity(const QString&)) );
+  connect(addIdentityButton,SIGNAL (clicked()),this,SLOT(addIdentity()) );
 }
 
 PrefsPageIdentity::~PrefsPageIdentity()
@@ -114,59 +142,102 @@ PrefsPageIdentity::~PrefsPageIdentity()
 
 void PrefsPageIdentity::realNameChanged(const QString& newRealName)
 {
-  preferences->realname=newRealName;
+  identity->setRealName(newRealName);
 }
 
 void PrefsPageIdentity::loginChanged(const QString& newLogin)
 {
-  preferences->ident=newLogin;
+  identity->setIdent(newLogin);
 }
 
 // TODO: derive from QLineEdit and submit an index in the signal to
 //       avoid duplicate code like this
 void PrefsPageIdentity::nick0Changed(const QString& newNick)
 {
-  preferences->setNickname(0,newNick);
+  identity->setNickname(0,newNick);
 }
 
 void PrefsPageIdentity::nick1Changed(const QString& newNick)
 {
-  preferences->setNickname(1,newNick);
+  identity->setNickname(1,newNick);
 }
 
 void PrefsPageIdentity::nick2Changed(const QString& newNick)
 {
-  preferences->setNickname(2,newNick);
+  identity->setNickname(2,newNick);
 }
 
 void PrefsPageIdentity::nick3Changed(const QString& newNick)
 {
-  preferences->setNickname(3,newNick);
+  identity->setNickname(3,newNick);
 }
 
 void PrefsPageIdentity::partReasonChanged(const QString& newReason)
 {
-  preferences->setPartReason(newReason);
+  identity->setPartReason(newReason);
 }
 
 void PrefsPageIdentity::kickReasonChanged(const QString& newReason)
 {
-  preferences->setKickReason(newReason);
+  identity->setKickReason(newReason);
 }
 
 void PrefsPageIdentity::showAwayMessageChanged(int state)
 {
-  preferences->setShowAwayMessage(state==2);
+  identity->setShowAwayMessage(state==2);
 }
 
 void PrefsPageIdentity::awayMessageChanged(const QString& newMessage)
 {
-  preferences->setAwayMessage(newMessage);
+  identity->setAwayMessage(newMessage);
 }
 
 void PrefsPageIdentity::unAwayMessageChanged(const QString& newMessage)
 {
-  preferences->setUnAwayMessage(newMessage);
+  identity->setReturnMessage(newMessage);
+}
+
+void PrefsPageIdentity::updateIdentity(int number)
+{
+  identity=identities.at(number);
+
+  if(number==0) defaultText->show();
+  else defaultText->hide();
+
+  loginInput->setText(identity->getIdent());
+  realNameInput->setText(identity->getRealName());
+
+  nick0->setText(identity->getNickname(0));
+  nick1->setText(identity->getNickname(1));
+  nick2->setText(identity->getNickname(2));
+  nick3->setText(identity->getNickname(3));
+
+  partInput->setText(identity->getPartReason());
+  kickInput->setText(identity->getKickReason());
+
+  showAwayMessageCheck->setChecked(identity->getShowAwayMessage());
+  awayInput->setText(identity->getAwayMessage());
+  unAwayInput->setText(identity->getReturnMessage());
+}
+
+void PrefsPageIdentity::renameIdentity(const QString& newName)
+{
+  identity->setName(newName);
+  identityCombo->changeItem(newName,identityCombo->currentItem());
+}
+
+void PrefsPageIdentity::addIdentity()
+{
+  identity=new Identity();
+  identity->setName(i18n("New Identity"));
+
+  preferences->addIdentity(identity);
+  identities=preferences->getIdentityList();
+
+  identityCombo->insertItem(identity->getName());
+  identityCombo->setCurrentItem(identityCombo->count()-1);
+
+  updateIdentity(identityCombo->count()-1);
 }
 
 #include "prefspageidentity.moc"
