@@ -11,12 +11,18 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: prefspageidentity.h,v 1.5 2003/02/05 20:16:57 eisfuchs Exp $
+  $Id: prefspageidentity.h,v 1.8 2003/02/10 16:39:49 eisfuchs Exp $
 */
 
 #ifndef PREFSPAGEIDENTITY_H
 #define PREFSPAGEIDENTITY_H
 
+#include <qcheckbox.h>
+#include <qlabel.h>
+
+#include <klineedit.h>
+#include <kcombobox.h>
+
 #include "prefspage.h"
 
 /*
@@ -34,15 +40,46 @@ class PrefsPageIdentity : public PrefsPage
   protected slots:
     void realNameChanged(const QString& newRealName);
     void loginChanged(const QString& newlogin);
+
     void nick0Changed(const QString& newNick);
     void nick1Changed(const QString& newNick);
     void nick2Changed(const QString& newNick);
     void nick3Changed(const QString& newNick);
+
     void partReasonChanged(const QString& newReason);
     void kickReasonChanged(const QString& newReason);
+
     void showAwayMessageChanged(int state);
     void awayMessageChanged(const QString& newMessage);
     void unAwayMessageChanged(const QString& newMessage);
+
+    void updateIdentity(int number);
+    void renameIdentity(const QString& newName);
+
+    void addIdentity();
+
+  protected:
+    QPtrList<Identity> identities;
+    Identity* identity;
+
+    KComboBox* identityCombo;
+
+    QLabel* defaultText;
+
+    KLineEdit* realNameInput;
+    KLineEdit* loginInput;
+
+    KLineEdit* nick0;
+    KLineEdit* nick1;
+    KLineEdit* nick2;
+    KLineEdit* nick3;
+
+    KLineEdit* partInput;
+    KLineEdit* kickInput;
+
+    QCheckBox* showAwayMessageCheck;
+    KLineEdit* awayInput;
+    KLineEdit* unAwayInput;
 };
 
 #endif
