@@ -11,19 +11,18 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: query.h,v 1.8 2002/12/11 16:25:51 eisfuchs Exp $
+  $Id: query.h,v 1.13 2003/01/28 12:20:49 eisfuchs Exp $
 */
 
+#ifndef QUERY_H
+#define QUERY_H
+
 #include <qobject.h>
 #include <qvbox.h>
 #include <qiconset.h>
 #include <qcheckbox.h>
 
-#ifndef QUERY_H
-#define QUERY_H
-
 #include "chatwindow.h"
-#include "server.h"
 #include "ircinput.h"
 
 /*
@@ -42,20 +41,24 @@ class Query : public ChatWindow
 
     void setName(const QString& newName);
     void setHostmask(const QString& newHostmask);
-    void setServer(Server* setServer);
+    void updateFonts();
 
   signals:
     void newText(QWidget* query);
     void closed(Query* query);
 
+  public slots:
+    void adjustFocus();
+
   protected slots:
     void queryTextEntered();
     void newTextInView();
     void close();
+    // connected to IRCInput::textPasted() - used to handle large/multiline pastes
+    void textPasted(QString text);
 
   protected:
-    int spacing();
-    int margin();
+    void sendQueryText(QString line);
 
     QString queryName;
     QString hostmask;
