@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: server.cpp,v 1.46 2003/02/07 10:19:42 eisfuchs Exp $
+  $Id: server.cpp,v 1.52 2003/02/20 17:01:03 eisfuchs Exp $
 */
 
 #include <unistd.h>
@@ -36,6 +36,7 @@
 Server::Server(int id)
 {
   QStringList serverEntry=QStringList::split(',',KonversationApplication::preferences.getServerById(id),true);
+  setIdentity(KonversationApplication::preferences.getIdentityByName(serverEntry[7]));
 
   tryNickNumber=0;
   checkTime=0;
@@ -43,7 +44,8 @@ Server::Server(int id)
   lastDccDir="";
 
   serverWindow=new ServerWindow(this);
-  setNickname(KonversationApplication::preferences.getNickname(tryNickNumber));
+  setNickname(identity.getNickname(tryNickNumber));
+  serverWindow->setIdentity(getIdentity());
   serverWindow->show();
 
   serverName=serverEntry[1];
@@ -70,6 +72,7 @@ Server::Server(int id)
   completeQueryPosition=0;
 
   inputFilter.setServer(this);
+  outputFilter.setIdentity(identity);
 
   incomingTimer.start(10);
 
@@ -174,9 +177,9 @@ void Server::connectToIRCServer()
       serverWindow->appendToStatus(i18n("Info"),i18n("Connected! Logging in ..."));
 
       QString connectString="USER " +
-                            KonversationApplication::preferences.ident +
+                            identity.getIdent() +
                             " 8 * :" +  // 8 = +i; 4 = +w
-                            KonversationApplication::preferences.realname;
+                            identity.getRealName();
 
       if(serverKey) queue("PASS "+serverKey);
       queue("NICK "+getNickname());
@@ -274,7 +277,7 @@ void Server::notifyTimeout()
   }
 
   // if no ISON was sent, fall back to PING for lag measuring
-  if(!sent) queue("PING LAG :"+ircName);
+  if(!sent) queue("PING LAG :"+getIrcName());
   // start check timer waiting for 303 or PONG response
   startNotifyCheckTimer();
 }
@@ -303,7 +306,7 @@ QString Server::getNextNickname()
   {
     tryNickNumber++;
     if(tryNickNumber==4) newNick=getNickname()+"_";
-    else newNick=KonversationApplication::preferences.getNickname(tryNickNumber);
+    else newNick=identity.getNickname(tryNickNumber);
   }
   return newNick;
 }
@@ -419,6 +422,7 @@ void Server::addQuery(const QString& nickname,const QString& hostmask)
   {
     query=new Query(serverWindow->getWindowContainer());
     query->setServer(this);
+    query->setIdentity(getIdentity());
     query->setName(nickname);
     // Add new query pane to tabwidget
     serverWindow->addView(query,0,nickname);
@@ -432,6 +436,18 @@ void Server::addQuery(const QString& nickname,const QString& hostmask)
   query->setHostmask(hostmask);
 }
 
+void Server::closeQuery(const QString& name)
+{
+  Query* query=getQueryByName(name);
+  removeQuery(query);
+}
+
+void Server::closeChannel(const QString& name)
+{
+  outputFilter.parse(getNickname(),KonversationApplication::preferences.getCommandChar()+"PART",name);
+  queue(outputFilter.getServerOutput());
+}
+
 void Server::requestDccSend(QString recipient)
 {
   // if we don't have a recipient yet, let the user select one
@@ -685,6 +701,7 @@ void Server::joinChannel(QString& name,QString& hostmask,QString& key)
   channel=new Channel(serverWindow->getWindowContainer());
 
   channel->setServer(this);
+  channel->setIdentity(getIdentity());
   channel->setName(name);
   channel->setNickname(getNickname());
 //  channel->setKey(key);
@@ -978,9 +995,15 @@ QString& Server::getNickname()
   return nickname;
 }
 
-QString Server::parseWildcards(const QString& toParse,const QString& nickname,const QString& channelName,const QString& channelKey,QStringList* nickList,const QString& queryName,const QString& parameter)
+QString Server::parseWildcards(const QString& toParse,const QString& nickname,const QString& channelName,const QString& channelKey,const QString& nick,const QString& queryName,const QString& parameter)
+{
+  return parseWildcards(toParse,nickname,channelName,channelKey,QStringList::split(' ',nick),queryName,parameter);
+}
+
+QString Server::parseWildcards(const QString& toParse,const QString& nickname,const QString& channelName,const QString& channelKey,const QStringList& nickList,const QString& queryName,const QString& parameter)
 {
   // TODO: parameter handling. this line is only to suppress a compiler warning
+  //       since parameters are not functional yet
   parameter.lower();
   // cut button name from definition
   QString out(toParse.mid(toParse.find(',')+1));
@@ -1002,7 +1025,7 @@ QString Server::parseWildcards(const QString& toParse,const QString& nickname,co
   }
 
   kdDebug() << "Replacing placeholders in: " << out << endl;
-  out.replace(QRegExp("%u"),nickList->join(separator));
+  out.replace(QRegExp("%u"),nickList.join(separator));
   if(channelName) out.replace(QRegExp("%c"),channelName);
   out.replace(QRegExp("%o"),nickname);
   out.replace(QRegExp("%k"),channelKey);
@@ -1015,8 +1038,6 @@ QString Server::parseWildcards(const QString& toParse,const QString& nickname,co
   // finally replace all "%p" with "%"
   out.replace(QRegExp("%p"),"%");
 
-  delete nickList;
-
   return out;
 }
 
@@ -1025,6 +1046,11 @@ void Server::setIrcName(QString newIrcName)
   ircName=newIrcName;
 }
 
+const QString& Server::getIrcName()
+{
+  return ircName;
+}
+
 OutputFilter& Server::getOutputFilter()
 {
   return outputFilter;
@@ -1062,4 +1088,7 @@ void Server::unAway()
   isAway=false;
 }
 
+void Server::setIdentity(Identity newIdentity) { identity=newIdentity; }
+const Identity& Server::getIdentity() { return identity; }
+
 #include "server.moc"
