@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: server.h,v 1.25 2003/02/05 20:16:57 eisfuchs Exp $
+  $Id: server.h,v 1.29 2003/02/20 17:01:05 eisfuchs Exp $
 */
 
 #ifndef SERVER_H
@@ -26,6 +26,7 @@
 #include "inputfilter.h"
 #include "outputfilter.h"
 #include "ircserversocket.h"
+#include "identity.h"
 
 /*
   @author Dario Abatianni
@@ -44,6 +45,7 @@ class Server : public QObject
     ~Server();
 
     QString getServerName();
+    const Identity& getIdentity();
     int getPort();
     bool getAutoJoin();
     void setAutoJoin(bool on);
@@ -56,6 +58,7 @@ class Server : public QObject
     QString getNextNickname();
 
     void setIrcName(QString newIrcName);
+    const QString& getIrcName();
 
     void addNickToChannel(QString& channelName,QString& nickname,QString& hostmask,bool op,bool voice);
     void addHostmaskToNick(QString& sourceNick,QString& sourceHostmask);
@@ -100,7 +103,8 @@ class Server : public QObject
 
     Channel* getChannelByName(const char* name);
     Query* getQueryByName(const char* name);
-    QString parseWildcards(const QString& toParse,const QString& nickname,const QString& channelName,const QString& channelKey,QStringList* nickList,const QString& queryName,const QString& parameter);
+    QString parseWildcards(const QString& toParse,const QString& nickname,const QString& channelName,const QString& channelKey,const QStringList& nickList,const QString& queryName,const QString& parameter);
+    QString parseWildcards(const QString& toParse,const QString& nickname,const QString& channelName,const QString& channelKey,const QString& nick,const QString& queryName,const QString& parameter);
 
     QString getAutoJoinCommand();
 
@@ -117,6 +121,8 @@ class Server : public QObject
     void queue(const QString& buffer);
     void setNickname(const QString& newNickname);
     void addQuery(const QString& nickname,const QString& hostmask);
+    void closeQuery(const QString& name);
+    void closeChannel(const QString& name);
     void requestDccPanel();
     void requestCloseDccPanel();
     void addDccSend(QString recipient,QString file);
@@ -146,6 +152,7 @@ class Server : public QObject
 
   protected:
     void startNotifyCheckTimer();
+    void setIdentity(Identity newIdentity);
 
     unsigned int completeQueryPosition;
     unsigned int tryNickNumber;
@@ -153,6 +160,8 @@ class Server : public QObject
     QString serverName;
     int serverPort;
 
+    Identity identity;
+
     bool autoJoin;
     bool autoRejoin;
     bool autoReconnect;
