@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: serverwindow.cpp,v 1.38 2003/02/05 20:16:57 eisfuchs Exp $
+  $Id: serverwindow.cpp,v 1.44 2003/02/20 17:01:06 eisfuchs Exp $
 */
 
 #include <qdir.h>
@@ -20,6 +20,7 @@
 #include <kdebug.h>
 #include <kdialog.h>
 #include <kaccel.h>
+#include <kmessagebox.h>
 
 #include "serverwindow.h"
 #include "konversationapplication.h"
@@ -70,6 +71,7 @@ ServerWindow::ServerWindow(Server* newServer) : KMainWindow()
   addStatusView();
 
   connect( windowContainer,SIGNAL (currentChanged(QWidget*)),this,SLOT (changedView(QWidget*)) );
+  connect( windowContainer,SIGNAL (closeTab(QWidget*)),this,SLOT (closeTab(QWidget*)) );
 
   createGUI();
   readOptions();
@@ -114,6 +116,9 @@ void ServerWindow::setServer(Server* newServer)
   }
 
   server=newServer;
+
+  connect(this,SIGNAL (closeChannel(const QString&)),server,SLOT (closeChannel(const QString&)));
+  connect(this,SIGNAL (closeQuery(const QString&)),server,SLOT (closeQuery(const QString&)));
 }
 
 Server* ServerWindow::getServer()
@@ -121,6 +126,11 @@ Server* ServerWindow::getServer()
   return server;
 }
 
+void ServerWindow::setIdentity(const Identity& identity)
+{
+  filter.setIdentity(identity);
+}
+
 void ServerWindow::appendToStatus(const QString& type,const QString& message)
 {
   statusPanel->appendServerMessage(type,message);
@@ -189,6 +199,34 @@ void ServerWindow::previousTab()
   }
 }
 
+void ServerWindow::closeTab(QWidget* viewToClose)
+{
+  ChatWindow* view=(ChatWindow*) viewToClose;
+  QString viewName=view->getName();
+  ChatWindow::WindowType viewType=view->getType();
+
+  if(viewType==ChatWindow::Status)
+  {
+    int result= KMessageBox::warningYesNo(
+                  this,
+                  i18n("Do you really want to disconnect from %1?").arg(server->getIrcName()),
+                  i18n("Quit server"),
+                  KStdGuiItem::yes(),
+                  KStdGuiItem::no(),
+                  "QuitServerOnTabClose");
+
+    if(result==KMessageBox::Yes)
+    {
+      QString command=filter.parse(server->getNickname(),KonversationApplication::preferences.getCommandChar()+"quit","");
+      server->queue(filter.getServerOutput());
+    }
+  }
+  else if(viewType==ChatWindow::Channel)  emit closeChannel(viewName);
+  else if(viewType==ChatWindow::Query)    emit closeQuery(viewName);
+  else if(viewType==ChatWindow::DccChat);
+  else if(viewType==ChatWindow::DccPanel) closeDccPanel();
+}
+
 void ServerWindow::addDccPanel()
 {
   // if the panel wasn't open yet
@@ -242,6 +280,7 @@ void ServerWindow::addStatusView()
   statusPanel=new StatusPanel(getWindowContainer());
   addView(statusPanel,2,i18n("Status"));
   statusPanel->setServer(getServer());
+  statusPanel->setIdentity(getServer()->getIdentity());
 
   connect(statusPanel,SIGNAL (newText(QWidget*)),this,SLOT (newText(QWidget*)) );
 }
@@ -306,7 +345,7 @@ void ServerWindow::saveOptions()
 bool ServerWindow::queryExit()
 {
   kdDebug() << "ServerWindow::queryExit()" << endl;
-  QString command=filter.parse(server->getNickname(),"/quit","");
+  QString command=filter.parse(server->getNickname(),KonversationApplication::preferences.getCommandChar()+"quit","");
   server->queue(filter.getServerOutput());
 
   saveOptions();
@@ -444,6 +483,7 @@ void ServerWindow::openNicksOnlineWindow()
   {
     nicksOnlineWindow=new NicksOnline(KonversationApplication::preferences.getNicksOnlineSize());
     connect(nicksOnlineWindow,SIGNAL (editClicked()),this,SLOT (openNotify()) );
+    connect(nicksOnlineWindow,SIGNAL (doubleClicked(QListViewItem*)),this,SLOT (notifyAction(QListViewItem*)) );
     connect(nicksOnlineWindow,SIGNAL (closeClicked(QSize)),this,SLOT (closeNicksOnlineWindow(QSize)) );
     connect(server,SIGNAL (nicksNowOnline(QStringList)),nicksOnlineWindow,SLOT (setOnlineList(QStringList)) );
     nicksOnlineWindow->show();
@@ -459,6 +499,28 @@ void ServerWindow::closeNicksOnlineWindow(QSize newSize)
   nicksOnlineWindow=0;
 }
 
+void ServerWindow::notifyAction(QListViewItem* item)
+{
+  if(item)
+  {
+    // parse wildcards (toParse,nickname,channelName,nickList,queryName,parameter)
+    QString out=server->parseWildcards(KonversationApplication::preferences.getNotifyDoubleClickAction(),
+                                       server->getNickname(),
+                                       QString::null,
+                                       QString::null,
+                                       item->text(0),
+                                       QString::null,
+                                       QString::null);
+    // Send all strings, one after another
+    QStringList outList=QStringList::split('\n',out);
+    for(unsigned int index=0;index<outList.count();index++)
+    {
+      filter.parse(server->getNickname(),outList[index],QString::null);
+      server->queue(filter.getServerOutput());
+    } // endfor
+  }
+}
+
 void ServerWindow::openColorConfiguration()
 {
 	colorConfigurationDialog = new ColorConfiguration(KonversationApplication::preferences.getActionMessageColor(),
