@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: serverwindow.h,v 1.25 2003/02/05 20:16:57 eisfuchs Exp $
+  $Id: serverwindow.h,v 1.29 2003/02/20 17:01:07 eisfuchs Exp $
 */
 
 #ifndef SERVERWINDOW_H
@@ -53,6 +53,7 @@
 #include "statuspanel.h"
 #include "nicksonline.h"
 #include "dccpanel.h"
+#include "identity.h"
 
 class ServerWindow : public KMainWindow
 {
@@ -74,11 +75,14 @@ class ServerWindow : public KMainWindow
 
     void setServer(Server* server);
     Server* getServer();
+    void setIdentity(const Identity& identity);
     bool isFrontView(const ChatWindow* view);
 
   signals:
     void prefsChanged();
     void openPrefsDialog();
+    void closeChannel(const QString& name);
+    void closeQuery(const QString& name);
 
   public slots:
     void setNickname(const QString&);
@@ -94,6 +98,7 @@ class ServerWindow : public KMainWindow
     void addStatusView();
     void nextTab();
     void previousTab();
+    void closeTab(QWidget* tab);
     void addDccPanel();
     void closeDccPanel();      // remove dcc panel from view, but does not delete it
     void deleteDccPanel();     // deletes dcc panel from memory
@@ -116,7 +121,7 @@ class ServerWindow : public KMainWindow
 
     void openNicksOnlineWindow();
     void closeNicksOnlineWindow(QSize newSize);
-
+    void notifyAction(QListViewItem* item);
     void openButtons();
     void applyButtons(QStringList newList);
     void closeButtons(QSize newSize);
@@ -140,7 +145,6 @@ class ServerWindow : public KMainWindow
       StatusText,LagOMeter
     };
 
-    // TODO: get rid of this filter. It's only used to pass the quit message on client close
     OutputFilter filter;
     LedTabWidget* windowContainer;
     StatusPanel* statusPanel;   // TODO: to be moved into Server class?
